
## @knitr Datenbanken
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite(c("GO.db", "KEGG.db"))


## @knitr GO.db1
library(GO.db)


## @knitr GO.db
## Laden der Pakete
library(GO.db)
library(KEGG.db)


## @knitr GO.db2
library(KEGG.db)


## @knitr limmaGSEA
## Laden der Pakete
library(multtest)
library(limma)
## Laden der Daten
data(golub)
## Erzeuge Faktor mit den Gruppen
golub.cl <- factor(golub.cl, labels = c("ALL", "AML"))
## Stelle Designmatrix auf
Design <- model.matrix(~ 0 + golub.cl)
colnames(Design) <- c("ALL", "AML")
## Schätze die Parameter
fit <- lmFit(golub, Design)
## Wähle Kontraste zum Vergleich ALL vs AML
cont.matrix <- makeContrasts(ALLvsAML=ALL-AML, levels=Design)
## Passe die Parameterschätzung Kontraste an
fit2 <- contrasts.fit(fit, cont.matrix)
## Berechne den moderierten t-Test
res.limma <- eBayes(fit2)
## Berechne FDR und fold change
res.tab <- topTable(res.limma, number=Inf, adjust.method="BH", 
                    p.value=1, genelist=golub.gnames[,3])


## @knitr hu6800.db
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("hu6800.db")


## @knitr hu6800.db1
## Laden des Paketes
library(hu6800.db)


## @knitr Entrez
## Füge Entrez Gene IDs zur Ergebnistabelle hinzu
res.tab$Entrez <- unlist(mget(res.tab$ID, hu6800ENTREZID, ifnotfound=NA))


## @knitr golubEsets
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("golubEsets")


## @knitr golubEsets1
## Laden des Paketes
library(golubEsets)
## Laden des Datensatzes
data(Golub_Train)


## @knitr gUniv
## Extraktion des Gen-Universums
gUniv <- unique(unlist(mget(featureNames(Golub_Train), hu6800ENTREZID, 
                            ifnotfound=NA)))


## @knitr categoryCompare
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("categoryCompare")


## @knitr categoryCompare1
## Laden des Paketes
library(categoryCompare)


## @knitr gSig
## Auswahl aller Gene mit adjustiertem p-Wert < 0.05
## Liste der hochregulierten Gene
gSig.ho <- unique(res.tab$Entrez[res.tab$adj.P.Val < 0.05 & res.tab$logFC > 0])
## Liste der herunterregulierten Gene
gSig.ru <- unique(res.tab$Entrez[res.tab$adj.P.Val < 0.05 & res.tab$logFC < 0])


## @knitr ccGeneList
## Erzeugung der Genliste
gL.ho <- list(genes=gSig.ho, universe=gUniv, annotation='org.Hs.eg.db')
gL.ru <- list(genes=gSig.ru, universe=gUniv, annotation='org.Hs.eg.db')
gLists <- new("ccGeneList", list(hoch = gL.ho, runter = gL.ru), 
              ccType=c("BP","KEGG"))
gLists 


## @knitr seed
set.seed(123)


## @knitr ccEnrich
## Berechnung der Anreicherung
enrichLists <- ccEnrich(gLists)


## @knitr enrichLists
## Ausgabe der berechneten Anreicherungen
enrichLists


## @knitr pvalueCutoff
pvalueCutoff(enrichLists$BP) <- 0.001
enrichLists


## @knitr ccCompare
## Angabe der Optionen
ccOpts <- new("ccOptions", listNames=names(gLists), outType = 'none')
## Berechne Informationen für die graphische Darstellung
ccResults <- ccCompare(enrichLists, ccOpts)
ccResults


## @knitr ccOutCyt
## Erzeuge den Netzwerkgraph für BP
cw.BP <- ccOutCyt(ccResults$BP, ccOpts)


## @knitr breakEdges
## Teile den Netzwerkgraphen auf
breakEdges(cw.BP, cutoff=0.4)


## @knitr ccOutCyt-KEGG
## Erzeuge den Netzwerkgraph für KEGG
cw.KEGG <- ccOutCyt(ccResults$KEGG,ccOpts)


