
## @knitr beadarrayExampleData
## Installation der Pakete
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("beadarrayExampleData")
install.packages(pkgs = "RColorBrewer", repos = "http://cran.at.r-project.org")


## @knitr exampleBLData
## Lade die Pakete
library(beadarray)
library(illuminaHumanv3.db)
library(beadarrayExampleData)
library(RColorBrewer)
## Erzeuge Farbpalette
mycol <- brewer.pal(3, "Set1")
## Lade die Daten
data(exampleBLData)


## @knitr imageplot
## Verwendung von Paketname und :: stellt sicher, dass die richtige Funktion 
## aufgerufen wird. Es gibt einen potentiellen Namenskonflikt mit einer 
## gleichnamigen Funktion aus dem Paket marray.
beadarray::imageplot(exampleBLData, array = 2, low = mycol[2], high = mycol[1])


## @knitr showArrayMask
## Erzeuge Plot der maskierten Beadtypen
showArrayMask(exampleBLData, array = 2)


## @knitr outlierplot
## Erzeuge Ausreißer-Plot
outlierplot(exampleBLData, array = 2,
            lowOutlierCol = mycol[2], highOutlierCol = mycol[1])


## @knitr makeControlProfile
## Kontrollen für Beadarrays Version 2
library(illuminaHumanv2.db)
table(makeControlProfile("Humanv2")$Tag)
## Kontrollen für Beadarrays Version 3
table(makeControlProfile("Humanv3")$Tag)


## @knitr makeQCTable
## Übersicht über Kontroll-Beadtypen
makeQCTable(exampleBLData)


## @knitr combinedControlPlot
## Erzeuge Boxplots für die Kontroll-Beadtypen
combinedControlPlot(exampleBLData)


## @knitr poscontlot
## Plot der Positivkontrollen
poscontPlot(exampleBLData, array = 2, colList = mycol[2:3], 
            main = "Positivkontrollen")
## Füge Legende zum Plot hinzu
legend("topright", legend = c("Housekeeper", "Biotin"), fill = mycol[2:3])


## @knitr expressionQCPipeline
## Automatisierte Erzeugung von QC-Berichten im HTML-Format
expressionQCPipeline(exampleBLData, qcDir = "BeadLevelDataQC")


## @knitr exampleSummaryData
## Lade die Daten
data(exampleSummaryData)
exampleSummaryData


## @knitr fData
## Zeige ersten Zeilen (head) des Slots "featureData" (fData)
head(fData(exampleSummaryData))
## Absolute Häufigkeiten (table) des Status der Beadtypen
table(fData(exampleSummaryData)[, "Status"])


## @knitr nObservations
## Extrahiere die Signalintensitäten des grünen Kanals
exSumData <- channel(exampleSummaryData, "G")
## Boxplot der Anzahl der Beads pro Beadtyp
boxplot(exSumData, what = "nObservations")


## @knitr Status
## Boxplot der Signalintensitäten aufgeteilt nach BeadArray und Status
boxplot(exSumData, probeFactor = "Status")


## @knitr exprs
## Boxplot der Signalintensitäten aufgeteilt nach BeadArray
boxplot(exSumData)


## @knitr plotMAXY
## MA-Plots der Signalintensitäten
plotMAXY(exprs(exSumData), arrays = 7:9, log = FALSE)


## @knitr arrayQualityMetricsIllumina
## Lade das Paket
library(arrayQualityMetrics)
## Ersetze fehlenden Wert durch 0
exprs(exSumData)[is.na(exprs(exSumData)[,12]),12] <- 0


## @knitr arrayQualityMetricsIllumina1
## Erzeuge QC-Bericht
arrayQualityMetrics(exSumData, 
                    outdir = "arrayQualityMetricsIllumina",
                    force = TRUE,
                    ## Daten sind bereits log-transformiert
                    do.logtransform = FALSE)


## @knitr QClumiR
## Lade das Paket
library(lumi)
## Einlesen von "TumorAdjacent-probe-raw.txt" - ohne QC
Daten.lumi <- lumiR(file = "TumorAdjacent-probe-raw.txt", QC = FALSE)
Daten.lumi


## @knitr lumiQ
## QC der Daten
Daten.lumi <- lumiQ(Daten.lumi)
## Übersicht zu den QC-Informationen
summary(Daten.lumi, "QC")


## @knitr ControlProbeProfile
## Auswahl der Datei
controlFile <- system.file('doc', 'Control_Probe_Profile.txt', 
                           package='lumi')
## Einlesen der Datei
controlData <- getControlData(controlFile)


## @knitr plotControl
## Aufteilung des Graphikfensters in drei Unterfenster
par(mfrow = c(1,3))
## Plot von Mittelwert und SD der Negativkontrollen (log-Skala)
plotControlData(controlData, type='NEGATIVE', logMode = TRUE)
## Plot der Housekeeper
plotHousekeepingGene(controlData)
## Plot der Kontrollen für niedrige und hohe Stringenz
plotStringencyGene(controlData)


## @knitr plotIntens
## Aufteilung des Graphikfensters in zwei Unterfenster
par(mfrow = c(1,2))
## Erzeuge Plots der geschätzten Dichten
lumi::density(Daten.lumi)
## Boxplots der Signalintensitäten
lumi::boxplot(Daten.lumi, log = "y")


## @knitr pairs
## Paarweise Streudiagramme der BeadArrays 1-3
lumi::pairs(Daten.lumi[,1:3], smoothScatter=TRUE)


## @knitr MAplot
## Paarweise MA-Plots der BeadArrays 1-3
lumi::MAplot(Daten.lumi[,1:3], smoothScatter=TRUE)


## @knitr plotCV
## Dichte der CV-Werte
lumi::plot(Daten.lumi, what = "cv")


