
## @knitr multtest
## Installation des Paketes
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
biocLite("multtest")


## @knitr multtest1
## Lade das Paket
library(multtest)
## Lade den Datensatz
data(golub)


## @knitr golub
## Struktur (str) der Daten
str(golub)
## Umwandlung der Gruppenzugehörigkeit in einen Faktor (kategorielle Variable)
golub.cl <- factor(golub.cl, labels = c("ALL", "AML"))
table(golub.cl)


## @knitr samr
## Installation der Pakete
#source("http://bioconductor.org/biocLite.R")
library(BiocInstaller)
## Paket impute wird für samr benötigt
biocLite("impute")
install.packages("samr", repos = "http://cran.at.r-project.org/")


## @knitr samr1
## Lade das Paket
library(samr)


## @knitr samr2
## Zusammenstellung der Eingabedaten
Daten <- list(x = golub, y = golub.cl, logged2 = TRUE,
              genenames = golub.gnames[,3])
## Führe SAM durch
res.samr <- samr(data = Daten, resp.type = "Two class unpaired")


## @knitr samr.compute.delta.table
## Erzeuge die Delta-Tabelle
Delta.tab <- samr.compute.delta.table(res.samr, 
                                      dels = seq(0.8, 1.2, by = 0.02))


## @knitr Delta.tab
## Ausgabe der Spalten 1, 5 und 6
Delta.tab[,c(1,5,6)]


## @knitr samr-plot
## Stelle beobachtete und erwartete SAM-Werte dar
samr.plot(res.samr, del = 1.11)


## @knitr samr-plot2
## SAM-Werte unter Berücksichtigung der Größe der Veränderung (>= 100%)
samr.plot(res.samr, del = 1.11, min.foldchange = 2.0)


## @knitr compute-siggenes-table
## Auswahl der signifikanten Gene mit >= 50% Veränderung
res.samr.genes <- samr.compute.siggenes.table(res.samr, del = 1.11, 
                                              data = Daten, 
                                              delta.table = Delta.tab, 
                                              min.foldchange = 2.0)
## Struktur der Ergebnistabelle
str(res.samr.genes)


## @knitr limmaStats
## Laden des Paketes
library(limma)


## @knitr design
## Stelle Designmatrix auf
Design <- model.matrix(~ 0 + golub.cl)
## Umbenennung der Spalten der Designmatrix
colnames(Design) <- c("ALL", "AML")


## @knitr eBayes
## Schätze die Parameter
fit <- lmFit(golub, Design)
## Wähle Kontraste zum Vergleich ALL vs AML
cont.matrix <- makeContrasts(ALLvsAML=ALL-AML, levels=Design)
## Passe die Parameterschätzung an Kontraste an
fit2 <- contrasts.fit(fit, cont.matrix)
## Berechne den moderierten t-Test
res.limma <- eBayes(fit2)


## @knitr topTable
## Auswahl der Gene mit FDR < 0.06 und >= 100% Veränderung
res.limma.genes <- topTable(res.limma, number=Inf, adjust.method="BH", 
                            p.value=0.05, lfc=log2(2.0),
                            genelist=golub.gnames[,3])
## Struktur der Ergebnistabelle
str(res.limma.genes)


## @knitr volcanoplot
## Erzeuge Vulkanplot
volcanoplot(res.limma)
## Füge Grenzen der Bereich hinzu
abline(v = c(-log2(2.0), log2(2.0)), lwd = 2, col = "red",
       h = min(res.limma.genes$B))


## @knitr samrvslimma
## Vergleich der Ergebnisse von SAM und limma
genes.samr <- c(res.samr.genes$genes.up[,"Gene ID"], 
                res.samr.genes$genes.lo[,"Gene ID"])
## Signifikant bei SAM und limma
sum(genes.samr %in% res.limma.genes$ID)
## Signifikant bei SAM und nicht bei limma
sum(!(genes.samr %in% res.limma.genes$ID))


## @knitr samrvslimma1
## Unterschiede zwischen den beiden Analysen
unterschied <- genes.samr[!(genes.samr %in% res.limma.genes$ID)]
golub.gnames[golub.gnames[,3] %in% unterschied, 2]


## @knitr heatmap.plus
## Installation des Paketes
install.packages(c("heatmap.plus", "MKmisc"), 
                  repos = "http://cran.at.r-project.org/")


## @knitr heatmap.plus1
## Laden der Pakete
library(heatmap.plus)
library(RColorBrewer)
library(MKmisc)


## @knitr heatmap.plus2
## Auswahl der Gene
ind <- golub.gnames[,3] %in% res.limma.genes$ID
golub.ausw <- golub[ind,]
## Farbgebung
farbe <- rev(colorRampPalette(brewer.pal(10, "RdYlBu"))(128))
## Zentrierung der einzelnen Gene am Mittelwert macht die Gene vergleichbarer 
golub.ausw <- golub.ausw - rowMeans(golub.ausw)
## Anpassung und Zentrierung der Farben
farbe <- heatmapCol(data = golub.ausw, col =  farbe, lim = 1.5)
## Markierung der Gruppen: ALL = schwarz, AML = rot
clab <- cbind(as.character(as.integer(golub.cl)), 
              as.character(as.integer(golub.cl)))
## Erzeuge die Heatmap
heatmap.plus(golub.ausw, col = farbe, ColSideColors = clab)


