
## @knitr exampleBLData.prepro
## Laden der Pakete
library(beadarray)
library(beadarrayExampleData)
## Laden der Daten
data(exampleBLData)


## @knitr summarize
## Aggregation der Bead-Level-Daten
BSdata <- summarize(exampleBLData)


## @knitr RobLoxBioCIllum
## Laden des Paketes
library(RobLoxBioC)


## @knitr robloxbioc1
## Berechne Bead-Summary-Daten
BSdata.rmx <- robloxbioc(exampleBLData)


## @knitr robloxbioc2
## Überlick über den Unterschied zwischen den beiden Verfahren
summary(exprs(BSdata)-exprs(BSdata.rmx))


## @knitr lumiPrepro
## Laden des Paketes
library(lumi)


## @knitr TumorAdjacent
## Einlesen der Daten
BSDaten <- readBeadSummaryData(dataFile = "TumorAdjacent-probe-raw.txt",
                               skip = 0,
                               illuminaAnnotation = "Humanv2")
## Einlesen der Daten
Daten.lumi <- lumiR(file = "TumorAdjacent-probe-raw.txt", QC = FALSE)


## @knitr rankinvariant
## beadarray: Transformation und Normalisierung
eset.ri.beadarray <- normaliseIllumina(BSDaten, transform = "log2", 
                                       method = "rankInvariant")
## lumi: Transformation und Normalisierung
eset.ri.lumi <- rankinvariant(lumiT(Daten.lumi, method = "log2"))


## @knitr BoxplotsRI
## Boxplots der Differenz der Expressionswerte der beiden Implementationen
boxplot(exprs(eset.ri.beadarray)-exprs(eset.ri.lumi),
        main = "Vergleich der beiden Implementationen von rankinvariant")
## Füge Nulllinie hinzu
abline(h = 0)


## @knitr rsn
## beadarray: Transformation und Normalisierung
eset.rsn.beadarray <- normaliseIllumina(BSDaten, transform = "log2", 
                                        method = "rsn")
## lumi: Transformation und Normalisierung
eset.rsn.lumi <- rsn(lumiT(Daten.lumi, method = "log2"))


## @knitr rsnVgl
## Maximale absolute Abweichung
max(abs(exprs(eset.rsn.beadarray)-exprs(eset.rsn.lumi)))


## @knitr quantil
## beadarray: Transformation und Normalisierung
eset.qua.beadarray <- normaliseIllumina(BSDaten, transform = "vst", 
                                        method = "quantile")
## lumi: Transformation und Normalisierung
eset.qua.lumi <- lumiN(lumiT(Daten.lumi, method = "vst"), method = "quantile")


## @knitr BoxplotsQua
## Boxplots der Differenz der Expressionswerte der beiden Implementationen
boxplot(exprs(eset.qua.beadarray)-exprs(eset.qua.lumi),
        main = "Vergleich der beiden Implementationen der Quantilnormalisierung")
## Füge Nulllinie hinzu
abline(h = 0)


## @knitr vsnIllumina
## beadarray: Transformation und Normalisierung
eset.vsn <- lumiN(Daten.lumi, method = "vsn")


## @knitr boxplotsIllumina
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2, 3))
## Erzeuge die Boxplots
boxplot(exprs(eset.ri.beadarray), main = "beadarray: log2 + RI")
boxplot(exprs(eset.ri.lumi), main = "lumi: log2 + RI")
boxplot(exprs(eset.rsn.lumi), main = "log2 + RSN")
boxplot(exprs(eset.qua.beadarray), main = "beadarray: VST + Quantil")
boxplot(exprs(eset.qua.lumi), main = "lumi: VST + Quantil")
boxplot(exprs(eset.vsn), main = "VSN")


## @knitr meanSdPlotsIllumina
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2, 3))
## Erzeuge die Mittelwert-SD-Plots
meanSdPlot(exprs(eset.ri.beadarray), main = "beadarray: log2 + RI")
meanSdPlot(exprs(eset.ri.lumi), main = "lumi: log2 + RI")
meanSdPlot(exprs(eset.rsn.lumi), main = "log2 + RSN")
meanSdPlot(exprs(eset.qua.beadarray), main = "beadarray: VST + Quantil")
meanSdPlot(exprs(eset.qua.lumi), main = "lumi: VST + Quantil")
meanSdPlot(exprs(eset.vsn), main = "VSN")


## @knitr Detection
## Alle Beadtypen mit Detektions-p-Wert < 0.01
detekt <- Detection(eset.ri.beadarray) < 0.01
## alternativ möglich
## detekt <- detection(eset.ri.lumi) < 0.01

## Detektions-p-Wert < 0.01 bei wenigstens 4 Arrays
detekt4 <- rowSums(detekt) >= 4
## Auswahl der Beadtypen
eset.ri.beadarray.4 <- eset.ri.beadarray[detekt4,]
eset.ri.lumi.4 <- eset.ri.lumi[detekt4,]
eset.rsn.lumi.4 <- eset.rsn.lumi[detekt4,]
eset.qua.beadarray.4 <- eset.qua.beadarray[detekt4,]
eset.qua.lumi.4 <- eset.qua.lumi[detekt4,]
eset.vsn.4 <- eset.vsn[detekt4,]


## @knitr meanSdPlotsIllumina4
## Teile Graphikfenster in 2 Zeilen und 3 Spalten
par(mfrow = c(2, 3))
## Erzeuge die Mittelwert-SD-Plots
meanSdPlot(exprs(eset.ri.beadarray.4), main = "beadarray: log2 + RI")
meanSdPlot(exprs(eset.ri.lumi.4), main = "lumi: log2 + RI")
meanSdPlot(exprs(eset.rsn.lumi.4), main = "log2 + RSN")
meanSdPlot(exprs(eset.qua.beadarray.4), main = "beadarray: VST + Quantil")
meanSdPlot(exprs(eset.qua.lumi.4), main = "lumi: VST + Quantil")
meanSdPlot(exprs(eset.vsn.4), main = "VSN")


## @knitr corsIllumina
## Berechnung der Pearson-Korrelationen
## beadarray: log2 + rankinvariant
cor.ri.beadarray <- cor(exprs(eset.ri.beadarray))
## lumi: log2 + rankinvariant
cor.ri.lumi <- cor(exprs(eset.ri.lumi))
## log2 + RSN
cor.rsn <- cor(exprs(eset.rsn.lumi))
## beadarray: VST + Quantil
cor.qua.beadarray <- cor(exprs(eset.qua.beadarray))
## lumi: VST + Quantil
cor.qua.lumi <- cor(exprs(eset.qua.lumi))
## VSN
cor.vsn <- cor(exprs(eset.vsn))

## Auswahl der relevanten Korrelationen
ausw <- lower.tri(cor.ri.beadarray, diag = FALSE)
Korrelationen <- data.frame("beadarray RI" = cor.ri.beadarray[ausw],
                            "lumi RI" = cor.ri.lumi[ausw],
                            "RSN" = cor.rsn[ausw],
                            "beadarray Quantil" = cor.qua.beadarray[ausw],
                            "lumi Quantil" = cor.qua.lumi[ausw],
                            "VSN" = cor.vsn[ausw])
## Zusammenfassung der relevanten Korrelationen
summary(Korrelationen)


## @knitr genefilterIllumina
## Laden des Paketes
library(genefilter)


## @knitr distsIllumina
## Berechung der mittleren L1-Abstände
## beadarray: log2 + rankinvariant
dist2.ri.beadarray <- dist2(exprs(eset.ri.beadarray))
## lumi: log2 + rankinvariant
dist2.ri.lumi <- dist2(exprs(eset.ri.lumi))
## log2 + RSN
dist2.rsn <- dist2(exprs(eset.rsn.lumi))
## beadarray: VST + Quantil
dist2.qua.beadarray <- dist2(exprs(eset.qua.beadarray))
## lumi: VST + Quantil
dist2.qua.lumi <- dist2(exprs(eset.qua.lumi))
## VSN
dist2.vsn <- dist2(exprs(eset.vsn))

## Auswahl der relevanten L1-Abstände
ausw <- lower.tri(dist2.ri.beadarray, diag = FALSE)
L1.Abstände <- data.frame("beadarray RI" = dist2.ri.beadarray[ausw],
                          "lumi RI" = dist2.ri.lumi[ausw],
                          "RSN" = dist2.rsn[ausw],
                          "beadarray Quantil" = dist2.qua.beadarray[ausw],
                          "lumi Quantil" = dist2.qua.lumi[ausw],
                          "VSN" = dist2.vsn[ausw])
## Zusammenfassung der relevanten L1-Abstände
summary(L1.Abstände)


